;+
;RESIZE A TABLE OF NOI (NUMBER OF ITERATION)
;WITH INTERPOLATION FROM N to N'
;(N > N')
;
; USAGE:
; output = utility_for_noi_table(Nx, Ny, br,bl,ul,ur, Mx, My)
;
; INPUT: 
; Nx = number of cols of input table 
; Ny = number of rows     "     "
; br = bottom right value "     "
; bl = bottom left value  "     "
; ur = upper right value  "     "
; ul = upper left value   "     " 
; Mx = number of cols of output table
; My = number of rows of output table
;
; OUTPUT:
; a Mx X My array containing the computed values
; 
; KEYWORDS:
;   VERBOSE : print every phase of the computation (input table and output table)
;
; EXAMPLE: 
;    my_table = utility_for_noi_table(15,15,10,20,20,50,9,9,/VERBOSE)
; 
;
;-

pro my_print, tab, Nx, Ny
;print an 1D array as a Nx X Ny table 
;rotate(reform(tab,Nx,Ny),7)
for j=0,Ny-1 do begin    ;;ROWS
   tmp_string = ""
   for i=0,Nx-1 do begin
      tmp_string=tmp_string+strtrim(tab[i+Nx*(Ny-j-1)],1)+" "
   endfor
   print, tmp_string
endfor   
end



function utility_for_noi_table, Nx, Ny, bl,br,ul,ur, Mx, My, VERBOSE=verbose

if KEYWORD_SET(verbose) then verb = 1B else verb = 0B

;;;;;;;;;;;;;;;;;
;input section
;;;;;;;;;;;;;;;;;

;definition of the table
N=Nx*Ny
a=[[ul,ur],[bl,br]]    ;as done within "tecno_inaf"
a=float(rotate(a,7))   ; as done within "tecno_inaf"
tab=make_array(N,/LONG)
for k=0,N-1 do begin
   i=(k mod Nx) 
   j=(k / Nx) 
   d1=a[0,0]+(a[1,0]-a[0,0])/(Nx-1)*i 
   d2=a[0,1]+(a[1,1]-a[0,1])/(Nx-1)*i 
   d3=round(d1+(d2-d1)/(Ny-1)*j)
   tab[k]=d3
endfor

;print, tab[*]
if (verb) then my_print, tab, Nx, Ny
if (verb) then print, " " 

tab2=rotate(congrid(rotate(reform(tab,Nx,Ny),7),Mx,My,/INTERP),7)
;print, tab2[*]
if (verb) then my_print, tab2, Mx, My

return, tab2
end
